==> open-xchange-documents-ui_7.8.2.orig.tar.bz2: open-xchange-documents-ui-7.8.2/ui/apps/io.ox/office/presentation/model/numberformatter.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH.
 *
 * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
 */

define.async('io.ox/office/presentation/model/numberformatter', [
    'io.ox/office/tk/locale/localedata',
    'io.ox/office/textframework/model/numberformatter'
], function (LocaleData, TextFormatter) {

    'use strict';

    // all predefined number format codes, mapped by category
    var categoryCodesDatabase = {};

    // load the localized number format definitions
    var numberFormatsPromise = LocaleData.loadResource('io.ox/office/presentation/resource/numberformats').done(function (data) {
        categoryCodesDatabase = data.categories;
    });

    // class NumberFormatter ==================================================

    /**
     * A number formatter for a Presentation document.
     *
     * @constructor
     *
     * @extends TextFormatter
     *
     * @param {PresentationModel} docModel
     *  The document model containing this instance.
     */
    var NumberFormatter = TextFormatter.extend({ constructor: function (docModel) {

        // self reference
        var self = this;

        // base constructor ---------------------------------------------------

        TextFormatter.call(this, docModel);

        // public methods -----------------------------------------------------

        /**
         * Returns an object containing the date components of the passed date
         * value as single numeric properties.
         *
         * @param {Date} date
         *  The date to be converted, as UTC or local date value.
         *
         * @param {Boolean} [local=false]
         *  Whether to extract the UTC date components (false, default), or the
         *  local date components (true).
         *
         * @returns {Object}
         *  The date components, in the properties 'Y' (full year), 'M' (zero-based
         *  month), and 'D' (one-based day in month).
         */
        this.getDateComponents = function (date, local) {
            return {
                Y: local ? date.getFullYear() : date.getUTCFullYear(),
                M: local ? date.getMonth() : date.getUTCMonth(),
                D: local ? date.getDate() : date.getUTCDate()
            };
        };

        /**
         * Returns an object containing the date and time components of the passed
         * date value as single numeric properties.
         *
         * @param {Date} date
         *  The date to be converted, as UTC or local date value.
         *
         * @param {Boolean} [local=false]
         *  Whether to extract the UTC date/time components (false, default), or
         *  the local date/time components (true).
         *
         * @returns {Object}
         *  The date and time components, in the properties 'Y' (full year), 'M'
         *  (zero-based month), 'D' (one-based day in month), 'h' (hours), 'm'
         *  (minutes), 's' (seconds), and 'ms' (milliseconds).
         */
        this.getDateTimeComponents = function (date, local) {
            var comps = self.getDateComponents(date, local);
            comps.h = local ? date.getHours() : date.getUTCHours();
            comps.m = local ? date.getMinutes() : date.getUTCMinutes();
            comps.s = local ? date.getSeconds() : date.getUTCSeconds();
            comps.ms = local ? date.getMilliseconds() : date.getUTCMilliseconds();
            return comps;
        };

        /**
         * Creates a UTC date value from the specified date and time components.
         *
         * @param {Object} comps
         *  The date/time components, in the properties 'Y', 'M', 'D', 'h', 'm',
         *  's', and 'ms', as returned by the function getDateTimeComponents().
         *
         * @returns {Date}
         *  The UTC date value representing the specified date and time.
         */
        this.makeDateTime = function (comps) {
            return new Date(Date.UTC(comps.Y, comps.M, comps.D, comps.h, comps.m, comps.s, comps.ms));
        };

        /**
         * Creates a UTC date value from the specified date components.
         *
         * @param {Object} comps
         *  The date components, in the properties 'Y', 'M', and 'D', as returned
         *  by the function getDateComponents().
         *
         * @returns {Date}
         *  The UTC date value representing the specified date. The time will be
         *  set to midnight.
         */
        this.makeDate = function (comps) {
            return new Date(Date.UTC(comps.Y, comps.M, comps.D, 0, 0, 0, 0));
        };

        /**
         * Returns all available number format codes for the specified format
         * category and current UI language.
         *
         * @param {String} category
         *  The identifier of the number format category.
         *
         * @returns {Array|Null}
         *  The format codes for the specified category, or null if no format
         *  codes have been defined for the category. Each element in the
         *  returned array is an object with the following properties:
         *  - {String} value
         *      The actual format code.
         *  - {String} label
         *      A caption label with a formatted example number, intended to be
         *      used in GUI form controls.
         *  - {Boolean} [red=false]
         *      If set to true, the format code contains a [RED] color modifier
         *      for negative numbers.
         */
        this.getCategoryCodes = function (category) {
            var categoryFormats = categoryCodesDatabase[category.toLocaleLowerCase()];
            return _.isArray(categoryFormats) ? _.copy(categoryFormats, true) : null;
        };

        // initialization -----------------------------------------------------

        // destroy all class members on destruction
        this.registerDestructor(function () {
            self = docModel = null;
        });

    } }); // class NumberFormatter

    // exports ================================================================

    return numberFormatsPromise.then(_.constant(NumberFormatter));

});

==> open-xchange-documents-ui_7.10.0.orig.tar.bz2: open-xchange-documents-ui-7.10.0/ui/apps/io.ox/office/presentation/model/numberformatter.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
 */

define.async('io.ox/office/presentation/model/numberformatter', [
    'io.ox/office/tk/locale/localedata',
    'io.ox/office/textframework/model/numberformatter'
], function (LocaleData, TextFormatter) {

    'use strict';

    // all predefined number format codes, mapped by category
    var categoryCodesDatabase = {};

    // load the localized number format definitions
    var numberFormatsPromise = LocaleData.loadResource('io.ox/office/presentation/resource/numberformats').done(function (data) {
        categoryCodesDatabase = (_.isObject(data) && data.categories) ? data.categories : {};
    });

    // class NumberFormatter ==================================================

    /**
     * A number formatter for a Presentation document.
     *
     * @constructor
     *
     * @extends TextFormatter
     *
     * @param {PresentationModel} docModel
     *  The document model containing this instance.
     */
    var NumberFormatter = TextFormatter.extend({ constructor: function (docModel) {

        // self reference
        var self = this;

        // base constructor ---------------------------------------------------

        TextFormatter.call(this, docModel);

        // public methods -----------------------------------------------------

        /**
         * Returns an object containing the date components of the passed date
         * value as single numeric properties.
         *
         * @param {Date} date
         *  The date to be converted, as UTC or local date value.
         *
         * @param {Boolean} [local=false]
         *  Whether to extract the UTC date components (false, default), or the
         *  local date components (true).
         *
         * @returns {Object}
         *  The date components, in the properties 'Y' (full year), 'M' (zero-based
         *  month), and 'D' (one-based day in month).
         */
        this.getDateComponents = function (date, local) {
            return {
                Y: local ? date.getFullYear() : date.getUTCFullYear(),
                M: local ? date.getMonth() : date.getUTCMonth(),
                D: local ? date.getDate() : date.getUTCDate()
            };
        };

        /**
         * Returns an object containing the date and time components of the passed
         * date value as single numeric properties.
         *
         * @param {Date} date
         *  The date to be converted, as UTC or local date value.
         *
         * @param {Boolean} [local=false]
         *  Whether to extract the UTC date/time components (false, default), or
         *  the local date/time components (true).
         *
         * @returns {Object}
         *  The date and time components, in the properties 'Y' (full year), 'M'
         *  (zero-based month), 'D' (one-based day in month), 'h' (hours), 'm'
         *  (minutes), 's' (seconds), and 'ms' (milliseconds).
         */
        this.getDateTimeComponents = function (date, local) {
            var comps = self.getDateComponents(date, local);
            comps.h = local ? date.getHours() : date.getUTCHours();
            comps.m = local ? date.getMinutes() : date.getUTCMinutes();
            comps.s = local ? date.getSeconds() : date.getUTCSeconds();
            comps.ms = local ? date.getMilliseconds() : date.getUTCMilliseconds();
            return comps;
        };

        /**
         * Creates a UTC date value from the specified date and time components.
         *
         * @param {Object} comps
         *  The date/time components, in the properties 'Y', 'M', 'D', 'h', 'm',
         *  's', and 'ms', as returned by the function getDateTimeComponents().
         *
         * @returns {Date}
         *  The UTC date value representing the specified date and time.
         */
        this.makeDateTime = function (comps) {
            return new Date(Date.UTC(comps.Y, comps.M, comps.D, comps.h, comps.m, comps.s, comps.ms));
        };

        /**
         * Creates a UTC date value from the specified date components.
         *
         * @param {Object} comps
         *  The date components, in the properties 'Y', 'M', and 'D', as returned
         *  by the function getDateComponents().
         *
         * @returns {Date}
         *  The UTC date value representing the specified date. The time will be
         *  set to midnight.
         */
        this.makeDate = function (comps) {
            return new Date(Date.UTC(comps.Y, comps.M, comps.D, 0, 0, 0, 0));
        };

        /**
         * Returns all available number format codes for the specified format
         * category and current UI language.
         *
         * @param {String} category
         *  The identifier of the number format category.
         *
         * @returns {Array|Null}
         *  The format codes for the specified category, or null if no format
         *  codes have been defined for the category. Each element in the
         *  returned array is an object with the following properties:
         *  - {String} value
         *      The actual format code.
         *  - {String} label
         *      A caption label with a formatted example number, intended to be
         *      used in GUI form controls.
         *  - {Boolean} [red=false]
         *      If set to true, the format code contains a [RED] color modifier
         *      for negative numbers.
         */
        this.getCategoryCodes = function (category) {
            var categoryFormats = categoryCodesDatabase[category.toLocaleLowerCase()];
            return _.isArray(categoryFormats) ? _.copy(categoryFormats, true) : null;
        };

        // initialization -----------------------------------------------------

        // destroy all class members on destruction
        this.registerDestructor(function () {
            self = docModel = null;
        });

    } }); // class NumberFormatter

    // exports ================================================================

    return numberFormatsPromise.then(_.constant(NumberFormatter));

});
